==> kubernetes-model-admissionregistration-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/TypeCheckingFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TypeCheckingFluent<A extends TypeCheckingFluent<A>> extends BaseFluent<A>{
  public TypeCheckingFluent() {
  }
  public TypeCheckingFluent(TypeChecking instance) {
    instance = (instance != null ? instance : new TypeChecking());

    if (instance != null) {
      this.withExpressionWarnings(instance.getExpressionWarnings());
      this.withExpressionWarnings(instance.getExpressionWarnings());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ArrayList<ExpressionWarningBuilder> expressionWarnings = new ArrayList<ExpressionWarningBuilder>();
  private Map<String,Object> additionalProperties;
  public A addToExpressionWarnings(int index,ExpressionWarning item) {
    if (this.expressionWarnings == null) {this.expressionWarnings = new ArrayList<ExpressionWarningBuilder>();}
    ExpressionWarningBuilder builder = new ExpressionWarningBuilder(item);
    if (index < 0 || index >= expressionWarnings.size()) { _visitables.get("expressionWarnings").add(builder); expressionWarnings.add(builder); } else { _visitables.get("expressionWarnings").add(index, builder); expressionWarnings.add(index, builder);}
    return (A)this;
  }
  public A setToExpressionWarnings(int index,ExpressionWarning item) {
    if (this.expressionWarnings == null) {this.expressionWarnings = new ArrayList<ExpressionWarningBuilder>();}
    ExpressionWarningBuilder builder = new ExpressionWarningBuilder(item);
    if (index < 0 || index >= expressionWarnings.size()) { _visitables.get("expressionWarnings").add(builder); expressionWarnings.add(builder); } else { _visitables.get("expressionWarnings").set(index, builder); expressionWarnings.set(index, builder);}
    return (A)this;
  }
  public A addToExpressionWarnings(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ExpressionWarning... items) {
    if (this.expressionWarnings == null) {this.expressionWarnings = new ArrayList<ExpressionWarningBuilder>();}
    for (ExpressionWarning item : items) {ExpressionWarningBuilder builder = new ExpressionWarningBuilder(item);_visitables.get("expressionWarnings").add(builder);this.expressionWarnings.add(builder);} return (A)this;
  }
  public A addAllToExpressionWarnings(Collection<ExpressionWarning> items) {
    if (this.expressionWarnings == null) {this.expressionWarnings = new ArrayList<ExpressionWarningBuilder>();}
    for (ExpressionWarning item : items) {ExpressionWarningBuilder builder = new ExpressionWarningBuilder(item);_visitables.get("expressionWarnings").add(builder);this.expressionWarnings.add(builder);} return (A)this;
  }
  public A removeFromExpressionWarnings(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ExpressionWarning... items) {
    if (this.expressionWarnings == null) return (A)this;
    for (ExpressionWarning item : items) {ExpressionWarningBuilder builder = new ExpressionWarningBuilder(item);_visitables.get("expressionWarnings").remove(builder); this.expressionWarnings.remove(builder);} return (A)this;
  }
  public A removeAllFromExpressionWarnings(Collection<ExpressionWarning> items) {
    if (this.expressionWarnings == null) return (A)this;
    for (ExpressionWarning item : items) {ExpressionWarningBuilder builder = new ExpressionWarningBuilder(item);_visitables.get("expressionWarnings").remove(builder); this.expressionWarnings.remove(builder);} return (A)this;
  }
  public A removeMatchingFromExpressionWarnings(Predicate<ExpressionWarningBuilder> predicate) {
    if (expressionWarnings == null) return (A) this;
    final Iterator<ExpressionWarningBuilder> each = expressionWarnings.iterator();
    final List visitables = _visitables.get("expressionWarnings");
    while (each.hasNext()) {
      ExpressionWarningBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  public List<ExpressionWarning> buildExpressionWarnings() {
    return expressionWarnings != null ? build(expressionWarnings) : null;
  }
  public ExpressionWarning buildExpressionWarning(int index) {
    return this.expressionWarnings.get(index).build();
  }
  public ExpressionWarning buildFirstExpressionWarning() {
    return this.expressionWarnings.get(0).build();
  }
  public ExpressionWarning buildLastExpressionWarning() {
    return this.expressionWarnings.get(expressionWarnings.size() - 1).build();
  }
  public ExpressionWarning buildMatchingExpressionWarning(Predicate<ExpressionWarningBuilder> predicate) {
    for (ExpressionWarningBuilder item: expressionWarnings) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public boolean hasMatchingExpressionWarning(Predicate<ExpressionWarningBuilder> predicate) {
    for (ExpressionWarningBuilder item: expressionWarnings) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withExpressionWarnings(List<ExpressionWarning> expressionWarnings) {
    if (this.expressionWarnings != null) { _visitables.get("expressionWarnings").clear();}
    if (expressionWarnings != null) {this.expressionWarnings = new ArrayList(); for (ExpressionWarning item : expressionWarnings){this.addToExpressionWarnings(item);}} else { this.expressionWarnings = null;} return (A) this;
  }
  public A withExpressionWarnings(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ExpressionWarning... expressionWarnings) {
    if (this.expressionWarnings != null) {this.expressionWarnings.clear(); _visitables.remove("expressionWarnings"); }
    if (expressionWarnings != null) {for (ExpressionWarning item :expressionWarnings){ this.addToExpressionWarnings(item);}} return (A) this;
  }
  public boolean hasExpressionWarnings() {
    return expressionWarnings != null && !expressionWarnings.isEmpty();
  }
  public A addNewExpressionWarning(String fieldRef,String warning) {
    return (A)addToExpressionWarnings(new ExpressionWarning(fieldRef, warning));
  }
  public ExpressionWarningsNested<A> addNewExpressionWarning() {
    return new ExpressionWarningsNested(-1, null);
  }
  public ExpressionWarningsNested<A> addNewExpressionWarningLike(ExpressionWarning item) {
    return new ExpressionWarningsNested(-1, item);
  }
  public ExpressionWarningsNested<A> setNewExpressionWarningLike(int index,ExpressionWarning item) {
    return new ExpressionWarningsNested(index, item);
  }
  public ExpressionWarningsNested<A> editExpressionWarning(int index) {
    if (expressionWarnings.size() <= index) throw new RuntimeException("Can't edit expressionWarnings. Index exceeds size.");
    return setNewExpressionWarningLike(index, buildExpressionWarning(index));
  }
  public ExpressionWarningsNested<A> editFirstExpressionWarning() {
    if (expressionWarnings.size() == 0) throw new RuntimeException("Can't edit first expressionWarnings. The list is empty.");
    return setNewExpressionWarningLike(0, buildExpressionWarning(0));
  }
  public ExpressionWarningsNested<A> editLastExpressionWarning() {
    int index = expressionWarnings.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last expressionWarnings. The list is empty.");
    return setNewExpressionWarningLike(index, buildExpressionWarning(index));
  }
  public ExpressionWarningsNested<A> editMatchingExpressionWarning(Predicate<ExpressionWarningBuilder> predicate) {
    int index = -1;
    for (int i=0;i<expressionWarnings.size();i++) { 
    if (predicate.test(expressionWarnings.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching expressionWarnings. No match found.");
    return setNewExpressionWarningLike(index, buildExpressionWarning(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TypeCheckingFluent that = (TypeCheckingFluent) o;
    if (!java.util.Objects.equals(expressionWarnings, that.expressionWarnings)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(expressionWarnings,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (expressionWarnings != null && !expressionWarnings.isEmpty()) { sb.append("expressionWarnings:"); sb.append(expressionWarnings + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ExpressionWarningsNested<N> extends ExpressionWarningFluent<ExpressionWarningsNested<N>> implements Nested<N>{
    ExpressionWarningsNested(int index,ExpressionWarning item) {
      this.index = index;
      this.builder = new ExpressionWarningBuilder(this, item);
    }
    ExpressionWarningBuilder builder;
    int index;
    public N and() {
      return (N) TypeCheckingFluent.this.setToExpressionWarnings(index,builder.build());
    }
    public N endExpressionWarning() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-admissionregistration-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/TypeCheckingFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class TypeCheckingFluent<A extends TypeCheckingFluent<A>> extends BaseFluent<A>{
  public TypeCheckingFluent() {
  }
  
  public TypeCheckingFluent(TypeChecking instance) {
    this.copyInstance(instance);
  }
  private ArrayList<ExpressionWarningBuilder> expressionWarnings = new ArrayList<ExpressionWarningBuilder>();
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(TypeChecking instance) {
    instance = (instance != null ? instance : new TypeChecking());
  
    if (instance != null) {
        this.withExpressionWarnings(instance.getExpressionWarnings());
        this.withExpressionWarnings(instance.getExpressionWarnings());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public A addToExpressionWarnings(int index,ExpressionWarning item) {
    if (this.expressionWarnings == null) {this.expressionWarnings = new ArrayList<ExpressionWarningBuilder>();}
    ExpressionWarningBuilder builder = new ExpressionWarningBuilder(item);
    if (index < 0 || index >= expressionWarnings.size()) { _visitables.get("expressionWarnings").add(builder); expressionWarnings.add(builder); } else { _visitables.get("expressionWarnings").add(index, builder); expressionWarnings.add(index, builder);}
    return (A)this;
  }
  
  public A setToExpressionWarnings(int index,ExpressionWarning item) {
    if (this.expressionWarnings == null) {this.expressionWarnings = new ArrayList<ExpressionWarningBuilder>();}
    ExpressionWarningBuilder builder = new ExpressionWarningBuilder(item);
    if (index < 0 || index >= expressionWarnings.size()) { _visitables.get("expressionWarnings").add(builder); expressionWarnings.add(builder); } else { _visitables.get("expressionWarnings").set(index, builder); expressionWarnings.set(index, builder);}
    return (A)this;
  }
  
  public A addToExpressionWarnings(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ExpressionWarning... items) {
    if (this.expressionWarnings == null) {this.expressionWarnings = new ArrayList<ExpressionWarningBuilder>();}
    for (ExpressionWarning item : items) {ExpressionWarningBuilder builder = new ExpressionWarningBuilder(item);_visitables.get("expressionWarnings").add(builder);this.expressionWarnings.add(builder);} return (A)this;
  }
  
  public A addAllToExpressionWarnings(Collection<ExpressionWarning> items) {
    if (this.expressionWarnings == null) {this.expressionWarnings = new ArrayList<ExpressionWarningBuilder>();}
    for (ExpressionWarning item : items) {ExpressionWarningBuilder builder = new ExpressionWarningBuilder(item);_visitables.get("expressionWarnings").add(builder);this.expressionWarnings.add(builder);} return (A)this;
  }
  
  public A removeFromExpressionWarnings(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ExpressionWarning... items) {
    if (this.expressionWarnings == null) return (A)this;
    for (ExpressionWarning item : items) {ExpressionWarningBuilder builder = new ExpressionWarningBuilder(item);_visitables.get("expressionWarnings").remove(builder); this.expressionWarnings.remove(builder);} return (A)this;
  }
  
  public A removeAllFromExpressionWarnings(Collection<ExpressionWarning> items) {
    if (this.expressionWarnings == null) return (A)this;
    for (ExpressionWarning item : items) {ExpressionWarningBuilder builder = new ExpressionWarningBuilder(item);_visitables.get("expressionWarnings").remove(builder); this.expressionWarnings.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromExpressionWarnings(Predicate<ExpressionWarningBuilder> predicate) {
    if (expressionWarnings == null) return (A) this;
    final Iterator<ExpressionWarningBuilder> each = expressionWarnings.iterator();
    final List visitables = _visitables.get("expressionWarnings");
    while (each.hasNext()) {
      ExpressionWarningBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<ExpressionWarning> buildExpressionWarnings() {
    return expressionWarnings != null ? build(expressionWarnings) : null;
  }
  
  public ExpressionWarning buildExpressionWarning(int index) {
    return this.expressionWarnings.get(index).build();
  }
  
  public ExpressionWarning buildFirstExpressionWarning() {
    return this.expressionWarnings.get(0).build();
  }
  
  public ExpressionWarning buildLastExpressionWarning() {
    return this.expressionWarnings.get(expressionWarnings.size() - 1).build();
  }
  
  public ExpressionWarning buildMatchingExpressionWarning(Predicate<ExpressionWarningBuilder> predicate) {
    for (ExpressionWarningBuilder item: expressionWarnings) { if(predicate.test(item)){ return item.build();} } return null;
  }
  
  public boolean hasMatchingExpressionWarning(Predicate<ExpressionWarningBuilder> predicate) {
    for (ExpressionWarningBuilder item: expressionWarnings) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withExpressionWarnings(List<ExpressionWarning> expressionWarnings) {
    if (this.expressionWarnings != null) { _visitables.get("expressionWarnings").clear();}
    if (expressionWarnings != null) {this.expressionWarnings = new ArrayList(); for (ExpressionWarning item : expressionWarnings){this.addToExpressionWarnings(item);}} else { this.expressionWarnings = null;} return (A) this;
  }
  
  public A withExpressionWarnings(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ExpressionWarning... expressionWarnings) {
    if (this.expressionWarnings != null) {this.expressionWarnings.clear(); _visitables.remove("expressionWarnings"); }
    if (expressionWarnings != null) {for (ExpressionWarning item :expressionWarnings){ this.addToExpressionWarnings(item);}} return (A) this;
  }
  
  public boolean hasExpressionWarnings() {
    return expressionWarnings != null && !expressionWarnings.isEmpty();
  }
  
  public A addNewExpressionWarning(String fieldRef,String warning) {
    return (A)addToExpressionWarnings(new ExpressionWarning(fieldRef, warning));
  }
  
  public ExpressionWarningsNested<A> addNewExpressionWarning() {
    return new ExpressionWarningsNested(-1, null);
  }
  
  public ExpressionWarningsNested<A> addNewExpressionWarningLike(ExpressionWarning item) {
    return new ExpressionWarningsNested(-1, item);
  }
  
  public ExpressionWarningsNested<A> setNewExpressionWarningLike(int index,ExpressionWarning item) {
    return new ExpressionWarningsNested(index, item);
  }
  
  public ExpressionWarningsNested<A> editExpressionWarning(int index) {
    if (expressionWarnings.size() <= index) throw new RuntimeException("Can't edit expressionWarnings. Index exceeds size.");
    return setNewExpressionWarningLike(index, buildExpressionWarning(index));
  }
  
  public ExpressionWarningsNested<A> editFirstExpressionWarning() {
    if (expressionWarnings.size() == 0) throw new RuntimeException("Can't edit first expressionWarnings. The list is empty.");
    return setNewExpressionWarningLike(0, buildExpressionWarning(0));
  }
  
  public ExpressionWarningsNested<A> editLastExpressionWarning() {
    int index = expressionWarnings.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last expressionWarnings. The list is empty.");
    return setNewExpressionWarningLike(index, buildExpressionWarning(index));
  }
  
  public ExpressionWarningsNested<A> editMatchingExpressionWarning(Predicate<ExpressionWarningBuilder> predicate) {
    int index = -1;
    for (int i=0;i<expressionWarnings.size();i++) { 
    if (predicate.test(expressionWarnings.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching expressionWarnings. No match found.");
    return setNewExpressionWarningLike(index, buildExpressionWarning(index));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TypeCheckingFluent that = (TypeCheckingFluent) o;
    if (!java.util.Objects.equals(expressionWarnings, that.expressionWarnings)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(expressionWarnings,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (expressionWarnings != null && !expressionWarnings.isEmpty()) { sb.append("expressionWarnings:"); sb.append(expressionWarnings + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ExpressionWarningsNested<N> extends ExpressionWarningFluent<ExpressionWarningsNested<N>> implements Nested<N>{
    ExpressionWarningsNested(int index,ExpressionWarning item) {
      this.index = index;
      this.builder = new ExpressionWarningBuilder(this, item);
    }
    ExpressionWarningBuilder builder;
    int index;
    
    public N and() {
      return (N) TypeCheckingFluent.this.setToExpressionWarnings(index,builder.build());
    }
    
    public N endExpressionWarning() {
      return and();
    }
    
  
  }

}
